%**************************************************************************
% This file is part of the MLS-C Library; you can redistribute it and/or 
% modify it under the terms of the GNU Lesser General Public License as 
% published by the Free Software Foundation; either version 3 of the 
% License,or any later version.
% This program is distributed in the hope that it will be useful but 
% WITHOUT ANY WARRANTY; without even the implied warranty of 
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General 
% Public License for more details.
% You should have received a copy of the GNU Lesser General Public License
% along with GNU; see the file COPYING.  If not, write to the Free Software
% Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
% or see <http://www.gnu.org/licenses/>.
%**************************************************************************
% Created by: 
%    E Nadal, M Ouallal, JJ Rodenas, F Chinesta and FJ Fuenmayor
%  
% Release 1.0  
% Date: 18/07/2014
%**************************************************************************

function plot_arc(XY1,XY2,XYC,ClockWise)
%% 
% This function is used to plot arcs of circumference
% given the starting and end points, the center of the 
% circumference and the sense to go from the starting to 
% the end point
%
% XY1 = coordinates of starting point
% XY2 = ....
% ....


nsegments = 50;

if ClockWise>=0; ClockWise=1;
else ClockWise=0;
end

Cart1=XY1-XYC;
Cart2=XY2-XYC;
% 
[Th1,Rad1]=cart2pol(Cart1(1),Cart1(2));
[Th2,Rad2]=cart2pol(Cart2(1),Cart2(2));
if abs(Rad1-Rad2)>100*eps
    error (['Rad1 ~= Rad2']);
end

%The general case (does not require any adjustment) is:
% ((Th1<Th2) && ~ClockWise) || ((Th2<Th1) &&  ClockWise) 

%Special cases
if ((Th1<Th2) && ClockWise) 
    Th2=Th2-2*pi();
elseif ((Th2<Th1) && ~ClockWise) 
    Th2=Th2+2*pi();
end

th    = Th1:(Th2-Th1)/nsegments:Th2;
xunit = Rad1 * cos(th) + XYC(1);
yunit = Rad1 * sin(th) + XYC(2);
plot(xunit, yunit);

end